BlocXLocalizations class abstract

Constructors

BlocXLocalizations()

Properties

close String
no setter
copyDetails String
no setter
details String
no setter
emptyListText String
no setter
errorDetailsCopied String
no setter
hashCode int
The hash code for this object.
no setterinherited
invalidEmail String
no setter
invalidPhoneNumber String
no setter
invalidUrl String
no setter
loadingText String
no setter
onlyAlphanumericAllowed String
no setter
onlyNumbersAllowed String
no setter
report String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItemsMustBeUnique String
no setter
somethingWentWrong String
no setter
thisFieldIsRequired String
no setter
tryAgain String
no setter
valuesDoNotMatch String
no setter

Methods

dateRangeError(DateTime minDate, DateTime maxDate) String
errorCodeMessage(BlocXErrorCode errorCode) String
exactLengthFieldError(int length) String
fileSizeMustBeSmallerThan(String format) String
greaterThanFieldError(int otherValue) String
lengthRangeError(dynamic minLength, dynamic maxLength) String
lessThanFieldError(int otherValue) String
maxDateError(DateTime maxDate) String
maxLengthError(dynamic maxLength) String
maxNumberOfItemsCanBeSelected(int max) String
maxValueError(num maxValue) String
minDateError(DateTime minDate) String
minLengthError(dynamic maxLength) String
minNumberOfItemsMustBeSelected(int min) String
minValueError(num minValue) String
mustBeAfterDateField(String otherFieldName) String
mustBeBeforeDateField(String otherFieldName) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numberRangeError(num minValue, num maxValue) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

localizations BlocXLocalizations
getter/setter pair