ReadableError class

Constructors

ReadableError({required String message, String? title, dynamic error, StackTrace? stackTrace})

Properties

error → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final
title String?
final

Methods

copyWith({String? message, String? title, dynamic error, StackTrace? stackTrace}) ReadableError
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited