BlocxDateRangeValidator class

Validator that ensures a DateTime value is within the inclusive range minDate, maxDate.

Inheritance

Constructors

BlocxDateRangeValidator({required DateTime minDate, required DateTime maxDate, Duration? duration})
Creates a validator that enforces the date to be within minDate and maxDate.

Properties

duration Duration?
Optional duration associated with the error messages.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maxDate DateTime
final
minDate DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateWithSingleError(DateTime value) String?
Validates the given value and returns a single error message if invalid.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited