validateWithSingleError method

  1. @override
String? validateWithSingleError(
  1. DateTime value
)
override

Validates the given value and returns a single error message if invalid.

Returns null if the value is valid.

This method must be implemented by subclasses to define custom validation logic.

Implementation

@override
String? validateWithSingleError(DateTime value) {
  if (value.isBefore(minDate) || value.isAfter(maxDate)) {
    return loc.dateRangeError(minDate, maxDate); // localized error message
  }
  return null;
}