duration property
Optional duration associated with the error messages.
Can be used by form systems that display timed errors.
Defaults to null.
Implementation
final Duration? duration;
Optional duration associated with the error messages.
Can be used by form systems that display timed errors.
Defaults to null.
final Duration? duration;