validate abstract method

List<String> validate(
  1. T value
)

Validates the given value and returns a list of error messages.

Returns an empty list if the value is valid.

Implementation

List<String> validate(T value);