BlocxFormStateFormSubmitted<F, E extends Enum> class

Inheritance

Constructors

BlocxFormStateFormSubmitted({required F formData, required dynamic submittedData})

Properties

checkingUniqueFields Set<E>
finalinherited
comesFromPreviousStep bool
finalinherited
errors Map<E, Set<String>>
finalinherited
fieldsFetchingInfo Set<E>
finalinherited
formData → F
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldListen bool
finalinherited
shouldRebuild bool
finalinherited
step int
finalinherited
submittedData → dynamic
final

Methods

allErrors(FieldNameProvider<E> nameProvider) String
inherited
errorByKey(E key) String?
inherited
isFetchingFieldInfo(E key) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited