BlocxFormValidator<F extends BaseFormEntity<F, E> , E extends Enum> class
abstract
Base class for form validators that validates an entire form entity.
Subclasses should provide a list of fields (keys) and the corresponding validators for each field (validatorsByField).
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
F formData) → Map< E, List< TimedErrorMessage> > -
Validates the entire
formDataand returns a map of errors per field. -
validatorsByField(
E key, F formData) → List< BlocxFieldValidator> - Returns the list of validators for a specific field.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited