BlocxIntegerLessThanFieldValidator<F extends BlocxBaseFormEntity<F, E> , E extends Enum> class
- Inheritance
-
- Object
- BlocxFieldValidator<
F, E, int> - BlocxIntegerLessThanFieldValidator
Constructors
- BlocxIntegerLessThanFieldValidator(E otherKey, String otherFieldName)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- otherFieldName → String
-
final
- otherKey → E
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
F form, E key, int value) → String? -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited