validateWithSingleError method

  1. @override
String? validateWithSingleError(
  1. String value
)
override

Validates the given value and returns a single error message if invalid.

Returns null if the value is valid.

This method must be implemented by subclasses to define custom validation logic.

Implementation

@override
String? validateWithSingleError(String value) {
  final length = value.trim().length;

  if (length < minLength || length > maxLength) {
    return loc.lengthRangeError(minLength, maxLength);
  }

  return null;
}