BlocxMaxValueValidator<T extends num> class

Validator that ensures a numeric field is less than or equal to maxValue.

Inheritance

Constructors

BlocxMaxValueValidator(T maxValue, {Duration? duration})

Properties

duration Duration?
Optional duration associated with the error messages.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maxValue → T
The maximum allowed value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateWithSingleError(T value) String?
Validates the given value and returns a single error message if invalid.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited