BlocxMinLengthValidator class
Validator that ensures a string field has at least minLength characters.
- Inheritance
-
- Object
- BlocxFieldValidator<
String> - BlocxSingleErrorFieldValidator<
String> - BlocxMinLengthValidator
Constructors
- BlocxMinLengthValidator(int minLength, {Duration? duration})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateWithSingleError(
String value) → String? -
Validates the given
valueand returns a single error message if invalid.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited