BlocxRangeValueValidator class

Validator that ensures a numeric field is within the inclusive range minValue, maxValue.

Inheritance

Constructors

BlocxRangeValueValidator({required num minValue, required num maxValue, Duration? duration})

Properties

duration Duration?
Optional duration associated with the error messages.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maxValue num
final
minValue num
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateWithSingleError(num value) String?
Validates the given value and returns a single error message if invalid.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited