FormValidationMode enum

Defines when a form should validate.

Inheritance
Available extensions

Values

onSubmit → const FormValidationMode

Validate only when the form is submitted.

onUserInteraction → const FormValidationMode

Validate changed fields during user interaction and validate the full form on submit.

always → const FormValidationMode

Validate the full form on every field update and on submit.

none → const FormValidationMode

Disable validation completely.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FormValidationMode>
A constant List of the values in this enum, in order of their declaration.