BlocxCollectionEvent<T extends BlocxBaseEntity> class
Base class for all list-related events.
Extend this to define actions that mutate or interact with a BlocxCollectionBloc.
- Inheritance
- Implementers
- BlocxCollectionEventAddItem
- BlocxCollectionEventClearHighlightedItem
- BlocxCollectionEventClearSearch
- BlocxCollectionEventClearSelection
- BlocxCollectionEventCollapseItem
- BlocxCollectionEventDeselectItem
- BlocxCollectionEventDeselectMultipleItems
- BlocxCollectionEventExpandItem
- BlocxCollectionEventHighlightItem
- BlocxCollectionEventHighlightScrolledToItems
- BlocxCollectionEventLoadInitialPage
- BlocxCollectionEventLoadNextPage
- BlocxCollectionEventRefreshData
- BlocxCollectionEventRemoveItem
- BlocxCollectionEventRemoveItemById
- BlocxCollectionEventRemoveMultipleItems
- BlocxCollectionEventReplaceList
- BlocxCollectionEventScrollToIdentifier
- BlocxCollectionEventScrollToItem
- BlocxCollectionEventSearch
- BlocxCollectionEventSearchNextPage
- BlocxCollectionEventSearchRefresh
- BlocxCollectionEventSelectItem
- BlocxCollectionEventSelectMultipleItems
- BlocxCollectionEventToggleItemExpansion
- BlocxCollectionEventUpdateItem
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited