BlocxCollectionEventLoadInitialPage<T extends BlocxBaseEntity, P> class

Loads the initial page of data into the list.

payload can hold request parameters such as filters, paging info, or repository instructions.

Inheritance

Constructors

BlocxCollectionEventLoadInitialPage({required P? payload})

Properties

hashCode int
The hash code for this object.
no setterinherited
payload → P?
Optional request payload (e.g. filter, page size, etc.).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited