BlocxCollectionEventRemoveItemById<T extends BlocxBaseEntity> class

Removes a single item from the list.

Inheritance

Constructors

BlocxCollectionEventRemoveItemById({required String identifier})

Properties

hashCode int
The hash code for this object.
no setterinherited
identifier String
The item to remove.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited