BlocxCollectionEventScrollToIdentifier<T extends BlocxBaseEntity> class

Scrolls the list to an item identified by a string BlocxBaseEntity.identifier.

Useful when you only know the item’s identifier (e.g. a username), instead of having the full entity in memory.

Inheritance

Constructors

BlocxCollectionEventScrollToIdentifier({required String identifier, bool highlightItem = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
highlightItem bool
Whether the item should be highlighted after scrolling.
final
identifier String
The unique identifier of the target item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited