BlocxCollectionEventScrollToItem<T extends BlocxBaseEntity> class
Scrolls the list to a given item.
Optionally highlightItem to emphasize it once scrolled into view.
- Inheritance
-
- Object
- BaseEvent
- BlocxCollectionEvent<
T> - BlocxCollectionEventScrollToItem
Constructors
- BlocxCollectionEventScrollToItem({required T item, bool highlightItem = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightItem → bool
-
Whether the item should be highlighted after scrolling.
final
- item → T
-
The target item to scroll to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited