BlocxCollectionState<T extends BlocxBaseEntity> class
abstract
- Inheritance
- Implementers
- Available extensions
Constructors
-
BlocxCollectionState({required List<
T> list, required bool hasReachedEnd, required bool isLoadingNextPage, required bool isRefreshing, required bool isSearching, Set<String> selectedItemIds = const {}, Set<String> beingSelectedItemIds = const {}, Set<String> highlightedItemIds = const {}, Set<String> beingRemovedItemIds = const {}, Set<String> expandedItemIds = const {}, dynamic additionalInfo, required bool shouldRebuild, required bool shouldListen}) -
const
Properties
- additionalInfo → dynamic
-
final
-
beingRemovedItemIds
→ Set<
String> -
final
-
beingSelectedItemIds
→ Set<
String> -
final
-
expandedItemIds
→ Set<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasReachedEnd → bool
-
final
- hasSelection → bool
-
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extensionno setter -
highlightedItemIds
→ Set<
String> -
final
- isBusy → bool
-
Available on BlocxCollectionState<
Useful for quick guards in UIT> , provided by the ListStateExtensions extensionno setter - isEmpty → bool
-
no setter
- isLoadingNextPage → bool
-
final
- isRefreshing → bool
-
final
- isSearching → bool
-
final
-
list
→ List<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedCount → int
-
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extensionno setter -
selectedItemIds
→ Set<
String> -
final
-
selectedItems
→ List<
T> -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extensionno setter - shouldListen → bool
-
finalinherited
- shouldRebuild → bool
-
finalinherited
Methods
-
firstSelectedItemOrNull(
) → T? -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
indexOfId(
String id) → int -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isBeingRemoved(
T item) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isBeingRemovedId(
String id) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isBeingSelected(
T item) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isBeingSelectedId(
String id) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isExpanded(
T item) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isHighlighted(
T item) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isHighlightedId(
String id) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isSelected(
T item) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
isSelectedId(
String id) → bool -
Available on BlocxCollectionState<
T> , provided by the ListStateExtensions extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited