BlocxCollectionStateLoaded<T extends BlocxBaseEntity> class

Inheritance
Available extensions

Constructors

BlocxCollectionStateLoaded({required List<T> list, required bool hasReachedEnd, required bool isLoadingNextPage, required bool isRefreshing, required bool isSearching, required Set<String> selectedItemIds, required Set<String> beingSelectedItemIds, required Set<String> highlightedItemIds, required Set<String> beingRemovedItemIds, required Set<String> expandedItemIds, dynamic additionalInfo})
const

Properties

additionalInfo → dynamic
finalinherited
beingRemovedItemIds Set<String>
finalinherited
beingSelectedItemIds Set<String>
finalinherited
expandedItemIds Set<String>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasReachedEnd bool
finalinherited
hasSelection bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

no setter
highlightedItemIds Set<String>
finalinherited
isBusy bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

Useful for quick guards in UI
no setter
isEmpty bool
no setterinherited
isLoadingNextPage bool
finalinherited
isRefreshing bool
finalinherited
isSearching bool
finalinherited
list List<T>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCount int

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

no setter
selectedItemIds Set<String>
finalinherited
selectedItems List<T>

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

no setter
shouldListen bool
finalinherited
shouldRebuild bool
finalinherited

Methods

copyWith({List<T>? list, bool? hasReachedEnd, bool? isLoadingNextPage, bool? isRefreshing, bool? isSearching, Set<String>? selectedItemIds, Set<String>? beingSelectedItemIds, Set<String>? highlightedItemIds, Set<String>? beingRemovedItemIds, Set<String>? expandedItemIds, Object? additionalInfo}) BlocxCollectionStateLoaded<T>
firstSelectedItemOrNull() → T?

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

indexOfId(String id) int

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isBeingRemoved(T item) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isBeingRemovedId(String id) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isBeingSelected(T item) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isBeingSelectedId(String id) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isExpanded(T item) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isHighlighted(T item) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isHighlightedId(String id) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isSelected(T item) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

isSelectedId(String id) bool

Available on BlocxCollectionState<T>, provided by the ListStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited