BlocxInfiniteListStateRefresh class
- Inheritance
-
- Object
- BaseState
- BlocxInfiniteListState
- BlocxInfiniteListStateRefresh
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasReachedEnd → bool
-
finalinherited
- isAtBottom → bool
-
finalinherited
- isAtTop → bool
-
finalinherited
- isIdle → bool
-
finalinherited
- isLoadingMore → bool
-
finalinherited
- isRefreshing → bool
-
finalinherited
- isScrollingUp → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldListen → bool
-
finalinherited
- shouldRebuild → bool
-
finalinherited
- swipeRefreshHeight → double
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited