DataInsertSource enum

Describes where in the list new items are inserted during a data load.

Inheritance
Available extensions

Values

init → const DataInsertSource

Initial page load — inserts at index 0, clears previous content.

nextPage → const DataInsertSource

Next-page load — appends to the end of the list.

refresh → const DataInsertSource

Pull-to-refresh — replaces from index 0.

Search result — inserts at index 0 into the search result list.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DataInsertSource>
A constant List of the values in this enum, in order of their declaration.