SelectionChangedData<T> class
Constructors
-
SelectionChangedData({required List<
T> selection, required bool wasSelected, required T item})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- item → T
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selection
→ List<
T> -
final
- wasSelected → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited