BlocxDateRangeValidator class
Validator that ensures a DateTime value is within the inclusive range minDate, maxDate.
- Inheritance
-
- Object
- BlocxFieldValidator<
DateTime> - BlocxSingleErrorFieldValidator<
DateTime> - BlocxDateRangeValidator
Constructors
- BlocxDateRangeValidator({required DateTime minDate, required DateTime maxDate, Duration? duration})
-
Creates a validator that enforces the date to be within
minDateandmaxDate.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateWithSingleError(
DateTime value) → String? -
Validates the given
valueand returns a single error message if invalid.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited