validateWithSingleError method
Validates the given value and returns a single error message if invalid.
Returns null if the value is valid.
This method must be implemented by subclasses to define custom validation logic.
Implementation
@override
String? validateWithSingleError(String value) {
final size = value.length;
return size != length ? loc.exactLengthFieldError(length) : null;
}