BlocxFieldValidator<F extends BlocxBaseFormEntity<F, E> , E extends Enum, T> class
abstract
- Implementers
- BlocxDateTimeAfterFieldValidator
- BlocxDateTimeBeforeFieldValidator
- BlocxDateTimeMaxValidator
- BlocxDateTimeMinValidator
- BlocxDateTimeRangeValidator
- BlocxDateTimeRequiredValidator
- BlocxDoubleMaxValueValidator
- BlocxDoubleMinValueValidator
- BlocxDoublePositiveValidator
- BlocxDoubleRangeValidator
- BlocxDoubleRequiredValidator
- BlocxFileMaxSizeValidator
- BlocxFileRequiredValidator
- BlocxIntegerGreaterThanFieldValidator
- BlocxIntegerLessThanFieldValidator
- BlocxIntegerMaxValueValidator
- BlocxIntegerMinValueValidator
- BlocxIntegerNonZeroValidator
- BlocxIntegerPositiveValidator
- BlocxIntegerRangeValidator
- BlocxIntegerRequiredValidator
- BlocxListMaxItemsValidator
- BlocxListMinItemsValidator
- BlocxListRequiredValidator
- BlocxListUniqueItemsValidator
- BlocxPhoneBasicFormatValidator
- BlocxPhoneE164Validator
- BlocxPhoneMaxLengthValidator
- BlocxPhoneMinLengthValidator
- BlocxPhoneRequiredValidator
- BlocxStringAlphanumericValidator
- BlocxStringEmailValidator
- BlocxStringExactLengthValidator
- BlocxStringLengthRangeValidator
- BlocxStringMatchValidator
- BlocxStringMaxLengthValidator
- BlocxStringMinLengthValidator
- BlocxStringNumericValidator
- BlocxStringRequiredValidator
- BlocxStringUrlValidator
Constructors
- BlocxFieldValidator()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
F form, E key, T value) → FutureOr< String?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited