submitUseCaseTask property
The use case task executed when the form is submitted.
Concrete form blocs can override this with a more specific task type.
Example:
@override
BlocxUseCaseTask<CreateCategoryInput, CategoryResponse>
get submitUseCaseTask {
return BlocxUseCaseTask<CreateCategoryInput, CategoryResponse>(
useCase: createCategoryUseCase,
inputBuilder: () => CreateCategoryInput(
code: formData.code,
name: formData.name,
),
);
}
Implementation
BlocxUseCaseTask<Object?, Object?> get submitUseCaseTask;