BlocxFormState<F, E extends Enum> class
- Inheritance
- Implementers
Constructors
Properties
-
checkingUniqueFields
→ Set<
E> -
final
- comesFromPreviousStep → bool
-
final
-
errors
→ Map<
E, Set< String> > -
final
-
fieldsFetchingInfo
→ Set<
E> -
final
- formData → F
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldListen → bool
-
finalinherited
- shouldRebuild → bool
-
finalinherited
- step → int
-
final
Methods
-
allErrors(
FieldNameProvider< E> nameProvider) → String -
errorByKey(
E key) → String? -
isFetchingFieldInfo(
E key) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited