BlocxFormValidator<F extends BlocxBaseFormEntity<F, E> , E extends Enum> class
abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formKeys(
) → List< E> -
getValidatorsByKey(
F formData, E key) → List< BlocxFieldValidator< BlocxBaseFormEntity< >dynamic, Enum> , Enum, dynamic> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateField(
F formData, E key) → FutureOr< List< TimedErrorMessage> > -
validateForm(
F formData) → Future< Map< E, List< >TimedErrorMessage> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited