BlocxMaxDateValidator class
- Inheritance
-
- Object
- BlocxFieldValidator<
DateTime> - BlocxSingleErrorFieldValidator<
DateTime> - BlocxMaxDateValidator
Constructors
- BlocxMaxDateValidator(DateTime maxDate, {Duration? duration})
- Creates a validator that enforces the maximum allowed date.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateWithSingleError(
DateTime value) → String? -
Validates the given
valueand returns a single error message if invalid.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited