validateWithSingleError method

  1. @override
String? validateWithSingleError(
  1. T value
)
override

Validates the given value and returns a single error message if invalid.

Returns null if the value is valid.

This method must be implemented by subclasses to define custom validation logic.

Implementation

@override
String? validateWithSingleError(T value) {
  if (value > maxValue) {
    return loc.maxValueError(maxValue);
  }
  return null;
}