BlocxMinValueValidator<T extends num> class
Validator that ensures a numeric field is greater than or equal to minValue.
- Inheritance
-
- Object
- BlocxFieldValidator<
T> - BlocxSingleErrorFieldValidator<
T> - BlocxMinValueValidator
Constructors
- BlocxMinValueValidator(T minValue, {Duration? duration})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateWithSingleError(
T value) → String? -
Validates the given
valueand returns a single error message if invalid.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited