BlocxRangeValueValidator class
Validator that ensures a numeric field is within the inclusive range minValue, maxValue.
- Inheritance
-
- Object
- BlocxFieldValidator<
num> - BlocxSingleErrorFieldValidator<
num> - BlocxRangeValueValidator
Constructors
- BlocxRangeValueValidator({required num minValue, required num maxValue, Duration? duration})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateWithSingleError(
num value) → String? -
Validates the given
valueand returns a single error message if invalid.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited