BlocxCollectionEvent<T extends BlocxBaseEntity> class

Base class for all list-related events.

Extend this to define actions that mutate or interact with a BlocxCollectionBloc.

Inheritance
Implementers

Constructors

BlocxCollectionEvent()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited