BlocxCollectionEventCollapseItem<T extends BlocxBaseEntity> class
Collapses a specific item in the list (e.g. hide details).
- Inheritance
-
- Object
- BaseEvent
- BlocxCollectionEvent<
T> - BlocxCollectionEventCollapseItem
Constructors
- BlocxCollectionEventCollapseItem({required T item})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- item → T
-
The item to collapse.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited