BlocxCollectionEventRefreshData<T extends BlocxBaseEntity> class
Refreshes the current list data, reloading from the source.
- Inheritance
-
- Object
- BaseEvent
- BlocxCollectionEvent<
T> - BlocxCollectionEventRefreshData
Constructors
- BlocxCollectionEventRefreshData({bool clearSelection = false})
Properties
- clearSelection → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited