BlocxInfiniteListState class
- Inheritance
- Implementers
Constructors
- BlocxInfiniteListState({required bool shouldRebuild, required bool shouldListen, required bool isLoadingMore, required bool isRefreshing, required bool isIdle, required bool isScrollingUp, required bool isAtTop, required double swipeRefreshHeight, required bool isAtBottom, required bool hasReachedEnd})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasReachedEnd → bool
-
final
- isAtBottom → bool
-
final
- isAtTop → bool
-
final
- isIdle → bool
-
final
- isLoadingMore → bool
-
final
- isRefreshing → bool
-
final
- isScrollingUp → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldListen → bool
-
finalinherited
- shouldRebuild → bool
-
finalinherited
- swipeRefreshHeight → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited